Module casper_execution_engine::core::engine_state::engine_config [−][src]
Support for runtime configuration of the execution engine - as an integral property of the
EngineState instance.
Structs
The runtime configuration of the execution engine
Constants
Default value for maximum associated keys configuration option.
Default value for a maximum query depth configuration option.
Default value for maximum runtime call stack height configuration option.