Enum casper_execution_engine::core::engine_state::ExecError[][src]

pub enum ExecError {
Show 45 variants Interpreter(String), Storage(Error), BytesRepr(Error), NamedKeyNotFound(String), KeyNotFound(Key), AccountNotFound(Key), TypeMismatch(StoredValueTypeMismatch), InvalidAccess { required: AccessRights, }, ForgedReference(URef), URefNotFound(URef), FunctionNotFound(String), ParityWasm(Error), WasmOptimizer, GasLimit, Ret(Vec<URef>), Resolver(ResolverError), Revert(ApiError), AddKeyFailure(AddKeyFailure), RemoveKeyFailure(RemoveKeyFailure), UpdateKeyFailure(UpdateKeyFailure), SetThresholdFailure(SetThresholdFailure), SystemContract(Error), DeploymentAuthorizationFailure, ExpectedReturnValue, UnexpectedReturnValue, InvalidContext, IncompatibleProtocolMajorVersion { expected: u32, actual: u32, }, CLValue(CLValueError), HostBufferEmpty, UnsupportedWasmStart, NoActiveContractVersions(ContractPackageHash), InvalidContractVersion(ContractVersionKey), NoSuchMethod(String), WasmPreprocessing(PreprocessingError), KeyIsNotAURef(Key), UnexpectedStoredValueVariant, LockedContract(ContractPackageHash), InvalidContractPackage(ContractPackageHash), InvalidContract(ContractHash), InvalidContractWasm(ContractWasmHash), MissingArgument { name: String, }, DictionaryItemKeyExceedsLength, MissingSystemContractRegistry, MissingSystemContractHash(String), RuntimeStackOverflow,
}
Possible execution errors.

Variants

Interpreter(String)

Tuple Fields

0: String

WASM interpreter error.

Storage(Error)

Tuple Fields

0: Error

Storage error.

BytesRepr(Error)

Tuple Fields

0: Error

Failed to (de)serialize bytes.

NamedKeyNotFound(String)

Tuple Fields

0: String

Unable to find named key.

KeyNotFound(Key)

Tuple Fields

0: Key

Unable to find a key.

AccountNotFound(Key)

Tuple Fields

0: Key

Unable to find an account.

TypeMismatch(StoredValueTypeMismatch)

Tuple Fields

Type mismatch error.

InvalidAccess

Fields

required: AccessRights

Required access rights of the operation.

Invalid access.

ForgedReference(URef)

Tuple Fields

0: URef

Forged reference error.

URefNotFound(URef)

Tuple Fields

0: URef

Unable to find a URef.

FunctionNotFound(String)

Tuple Fields

0: String

Unable to find a function.

ParityWasm(Error)

Tuple Fields

0: Error

Parity WASM error.

WasmOptimizer

Error optimizing WASM.

GasLimit

Execution exceeded the gas limit.

Ret(Vec<URef>)

Tuple Fields

0: Vec<URef>

A stored smart contract incorrectly called a ret function.

Resolver(ResolverError)

Tuple Fields

Error using WASM host function resolver.

Revert(ApiError)

Tuple Fields

Reverts execution with a provided status

AddKeyFailure(AddKeyFailure)

Tuple Fields

Error adding an associated key.

RemoveKeyFailure(RemoveKeyFailure)

Tuple Fields

Error removing an associated key.

UpdateKeyFailure(UpdateKeyFailure)

Tuple Fields

Error updating an associated key.

SetThresholdFailure(SetThresholdFailure)

Tuple Fields

Error setting threshold on associated key.

SystemContract(Error)

Tuple Fields

0: Error

Error executing system contract.

DeploymentAuthorizationFailure

Weight of all used associated keys does not meet account’s deploy threshold.

ExpectedReturnValue

Host buffer expected a value to be present.

UnexpectedReturnValue

Host buffer was not expected to contain a value.

InvalidContext

Error calling a host function in a wrong context.

IncompatibleProtocolMajorVersion

Fields

expected: u32

Expected major version.

actual: u32

Actual major version supplied.

Unable to execute a deploy with invalid major protocol version.

CLValue(CLValueError)

Tuple Fields

Error converting a CLValue.

HostBufferEmpty

Unable to access host buffer.

UnsupportedWasmStart

WASM bytes contains an unsupported “start” section.

NoActiveContractVersions(ContractPackageHash)

Tuple Fields

Contract package has no active contract versions.

InvalidContractVersion(ContractVersionKey)

Tuple Fields

Invalid contract version supplied.

NoSuchMethod(String)

Tuple Fields

0: String

Contract does not have specified entry point.

WasmPreprocessing(PreprocessingError)

Tuple Fields

Error processing WASM bytes.

KeyIsNotAURef(Key)

Tuple Fields

0: Key

Unable to convert a Key into an URef.

UnexpectedStoredValueVariant

Unexpected variant of a stored value.

LockedContract(ContractPackageHash)

Tuple Fields

Error upgrading a locked contract package.

InvalidContractPackage(ContractPackageHash)

Tuple Fields

Unable to find a contract package by a specified hash address.

InvalidContract(ContractHash)

Tuple Fields

Unable to find a contract by a specified hash address.

InvalidContractWasm(ContractWasmHash)

Tuple Fields

Unable to find the WASM bytes specified by a hash address.

MissingArgument

Fields

name: String

Name of the required argument.

Error calling a smart contract with a missing argument.

DictionaryItemKeyExceedsLength

Error writing a dictionary item key which exceeded maximum allowed length.

MissingSystemContractRegistry

Missing system contract registry.

MissingSystemContractHash(String)

Tuple Fields

0: String

Missing system contract hash.

RuntimeStackOverflow

An attempt to push to the runtime stack which is already at the maximum height.

Implementations

Returns new type mismatch error.