Enum casper_execution_engine::core::engine_state::genesis::GenesisError [−][src]
pub enum GenesisError {
Show 15 variants
UnableToCreateRuntime,
InvalidMintKey,
MissingMintContract,
UnexpectedStoredValue,
ExecutionError(Error),
MintError(Error),
CLValue(String),
OrphanedDelegator {
validator_public_key: PublicKey,
delegator_public_key: PublicKey,
},
DuplicatedDelegatorEntry {
validator_public_key: PublicKey,
delegator_public_key: PublicKey,
},
InvalidDelegationRate {
public_key: PublicKey,
delegation_rate: DelegationRate,
},
InvalidBondAmount {
public_key: PublicKey,
},
InvalidDelegatedAmount {
public_key: PublicKey,
},
FailedToCreateSystemRegistry,
MissingSystemContractHash(String),
InvalidValidatorSlots {
validators: usize,
validator_slots: u32,
},
}Expand description
Error returned as a result of a failed genesis process.
Variants
UnableToCreateRuntime
Error creating a runtime.
InvalidMintKey
Error obtaining the mint’s contract key.
MissingMintContract
Missing mint contract.
UnexpectedStoredValue
Unexpected stored value variant.
ExecutionError(Error)
Tuple Fields
0: ErrorError executing a system contract.
MintError(Error)
Tuple Fields
0: ErrorError executing the mint system contract.
CLValue(String)
Tuple Fields
0: StringError converting a CLValue to a concrete type.
OrphanedDelegator
Fields
validator_public_key: PublicKeyValidator’s public key.
delegator_public_key: PublicKeyDelegator’s public key.
Specified validator does not exist among the genesis accounts.
DuplicatedDelegatorEntry
Fields
validator_public_key: PublicKeyValidator’s public key.
delegator_public_key: PublicKeyDelegator’s public key.
Duplicated delegator entry found for a given validator.
InvalidDelegationRate
Fields
public_key: PublicKeyDelegator’s public key.
delegation_rate: DelegationRateInvalid delegation rate specified in the genesis account entry.
Delegation rate outside the allowed range.
InvalidBondAmount
Fields
public_key: PublicKeyValidator’s public key.
Invalid bond amount in a genesis account.
InvalidDelegatedAmount
Fields
public_key: PublicKeyDelegator’s public key.
Invalid delegated amount in a genesis account.
FailedToCreateSystemRegistry
Failed to create system registry.
MissingSystemContractHash(String)
Tuple Fields
0: StringMissing system contract hash.
InvalidValidatorSlots
Fields
validators: usizeNumber of validators in the genesis config.
validator_slots: u32Number of validator slots specified.
Invalid number of validator slots configured.