[−][src]Struct casper_execution_engine::core::engine_state::genesis::GenesisAccount
Implementations
impl GenesisAccount[src]
pub fn system(balance: Motes, bonded_amount: Motes) -> Self[src]
pub fn new(
public_key: PublicKey,
account_hash: AccountHash,
balance: Motes,
bonded_amount: Motes
) -> Self[src]
public_key: PublicKey,
account_hash: AccountHash,
balance: Motes,
bonded_amount: Motes
) -> Self
pub fn public_key(&self) -> Option<PublicKey>[src]
pub fn account_hash(&self) -> AccountHash[src]
pub fn balance(&self) -> Motes[src]
pub fn bonded_amount(&self) -> Motes[src]
pub fn is_system_account(&self) -> bool[src]
Checks if a given genesis account belongs to a virtual system account,
pub fn is_genesis_validator(&self) -> bool[src]
Checks if a given genesis account is a valid genesis validator.
Genesis validators are the ones with a stake, and are not owned by a virtual system account.