Module casper_execution_engine::shared::newtypes[][src]

Some newtypes.

Structs

A correlation id is a unique identifier which can be used to track the progress of a given execution engine operation.