[−][src]Struct casper_execution_engine::shared::socket::Socket
Implementations
impl Socket[src]
pub fn new(socket: String) -> Self[src]
pub fn value(&self) -> String[src]
pub fn as_str(&self) -> &str[src]
pub fn get_path(&self) -> &Path[src]
pub fn remove_file(&self) -> Result<()>[src]
Safely removes file pointed out by a path.
In practice this tries to remove the file, and if the file does not exist, it ignores it, and propagates any other error.