[−][src]Trait casper_execution_engine::storage::transaction_source::Readable
A transaction with the capability to read from a given Handle.
Required methods
fn read(
&self,
handle: Self::Handle,
key: &[u8]
) -> Result<Option<Vec<u8>>, Self::Error>
&self,
handle: Self::Handle,
key: &[u8]
) -> Result<Option<Vec<u8>>, Self::Error>
Returns the value from the corresponding key from a given Transaction::Handle.