[−][src]Trait casper_execution_engine::storage::transaction_source::Transaction
A transaction which can be committed or aborted.
Associated Types
type Error
An error which can occur while reading or writing during a transaction, or committing the transaction.
type Handle
An entity which is being read from or written to during a transaction.
Required methods
Loading content...Provided methods
fn abort(self)
Aborts the transaction.
Any pending operations will not be saved.