[−][src]Struct casper_execution_engine::core::engine_state::MAX_PAYMENT
Methods from Deref<Target = U512>
pub const MAX: U512[src]
pub const fn low_u32(&self) -> u32[src]
Conversion to u32
pub const fn low_u64(&self) -> u64[src]
Low word (u64)
pub fn as_u32(&self) -> u32[src]
pub fn as_u64(&self) -> u64[src]
Conversion to u64 with overflow checking
Panics
Panics if the number is larger than u64::max_value().
pub fn as_usize(&self) -> usize[src]
Conversion to usize with overflow checking
Panics
Panics if the number is larger than usize::max_value().
pub fn is_zero(&self) -> bool[src]
Whether this is zero.
pub fn bits(&self) -> usize[src]
Return the least number of bits needed to represent the number
pub const fn bit(&self, index: usize) -> bool[src]
pub fn leading_zeros(&self) -> u32[src]
Returns the number of leading zeros in the binary representation of self.
pub fn trailing_zeros(&self) -> u32[src]
Returns the number of leading zeros in the binary representation of self.
pub const fn byte(&self, index: usize) -> u8[src]
pub fn to_big_endian(&self, bytes: &mut [u8])[src]
Write to the slice in big-endian format.
pub fn to_little_endian(&self, bytes: &mut [u8])[src]
Write to the slice in little-endian format.